import dataload.loadassets as loadassets
import pandas as pd


def processing(ticker: str, interval: str) -> pd.DataFrame:
    
    data = loadassets.load_data(ticker, interval)
    processed = loadassets.add_truedate(data)
    return processed


def load_daily(ticker: str) -> pd.DataFrame:
    return processing(ticker, 'D')

def load_15M(ticker: str) -> pd.DataFrame:
    return processing(ticker, '15M')

def load_5M(ticker: str) -> pd.DataFrame:
    return processing(ticker, '5M')


import pandas as pd
import datetime as dt

type filename = str
type ticker = str
type timeframe = str



ROOT = 'price_data/'

def load_data(ticker: ticker, interval: timeframe) -> pd.DataFrame:
    
    file_to_pull: filename = ROOT+ticker+'_'+interval+'.pkl'
    df: pd.DataFrame = pd.read_pickle(file_to_pull)
    return df

def true_date_processor(date: dt.datetime) -> dt.date:
    ADJ = dt.timedelta(days = 1)
    _d = date
    
    if date.hour >= 18:
        _d = _d + ADJ
        
    return _d.date()
    

def add_truedate(data: pd.DataFrame) -> pd.DataFrame:
    
    data['truedate'] = data['datetime'].apply(lambda x: true_date_processor(x)) #type: ignore
    return data

if __name__ == '__main__':
    data = load_data('ES','5M')
    processed = add_truedate(data)
    print(processed)
    
    




import datetime as dt
from dataclasses import dataclass
import pandas as pd
from enum import Enum, auto



type CandleArray = list[Candle]


class Dir(Enum):
    UP = auto()
    DOWN = auto()
    DOJI = auto()


@dataclass
class Candle:
    open: float
    high: float
    low: float 
    close: float
    time: dt.datetime
    bar_index: int
    
    @property
    def dir(self):
        x = ''
        if self.open>self.close:
            x = Dir.DOWN
        elif self.close>self.open:
            x = Dir.UP
        else:
            x = Dir.DOJI
        return x   

    @property
    def truedate(self)->dt.date:
        """
        function to generate truedate for a candle
        """
        
        
        truedate: dt.date = self.time
        if truedate.time() >= dt.time(18,0):
            truedate = self.time + dt.timedelta(1)
        
        truedate = truedate.date()
        return truedate

def to_candle_array(data: pd.DataFrame) -> CandleArray:
    candles: CandleArray = []
    
    for _, row in data.iterrows(): # type: ignore
        candle = Candle(row['open'],row['high'],row['low'],row['close'],row['datetime']) # type: ignore
        candles.append(candle) # type: ignore
    
    return candles
 

    


from setuptools import find_packages, setup

with open('app/Readme.md','r') as f:
    long_description = f.read()
    
setup(
    name = 'pricefunctions',
    version='0.0.10',
    description='tool that converts OHLC price tables to candles',
    package_dir={'':'app'},
    packages = find_packages(where='app'),
    long_description = long_description,
    long_description_content_type='text/markdown',
    author = 'RichCoastTrading',
    license='MIT',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.12',
        'Operating System :: OS Independent'
        ],
    install_requires = ['pandas >= 2.2.2'],
    extra_requires = {'dev':['twine >= 5.1.1']},
    )
    
    


import pandas as pd
import datetime as dt

def time_indices(date: dt.date, time: dt.time, data: pd.DataFrame) -> list[int]:
    data['time'] = data['datetime'].dt.time
    
    filtered = data[(data['time']== time) & (data['truedate'] == date)]
    inds = filtered.index #type: ignore
    
    
    index_list = [i for i in inds] #type: ignore
    
    return index_list #type: ignore


def generate_datarange(ind: int, dev: int, data: pd.DataFrame) -> pd.DataFrame:
    
    spliced = data.iloc[ind-dev:ind+dev]
    return spliced